Input

pub struct Input {
    pub url: Option<FHIRUri>,
    pub codeSystem: Option<CodeSystem>,
    pub code: Option<FHIRCode>,
    pub version: Option<FHIRString>,
    pub display: Option<FHIRString>,
    pub coding: Option<Coding>,
    pub codeableConcept: Option<CodeableConcept>,
    pub date: Option<FHIRDateTime>,
    pub abstract_: Option<FHIRBoolean>,
    pub displayLanguage: Option<FHIRCode>,
}

Fields

url: Option<FHIRUri>

CodeSystem URL. The server must know the code system (e.g. it is defined explicitly in the server’scode systems, or it is known implicitly by the server

codeSystem: Option<CodeSystem>

The codeSystem is provided directly as part of the request. Servers may choose not to accept code systems in this fashion. This parameter is used when the client wants the server to check against a code system that is not stored on the server

code: Option<FHIRCode>

The code that is to be validated

version: Option<FHIRString>

The version of the code system, if one was provided in the source data

display: Option<FHIRString>

The display associated with the code, if provided. If a display is provided a code must be provided. If no display is provided, the server cannot validate the display value, but may choose to return a recommended display name in an extension in the outcome. Whether displays are case sensitive is code system dependent

coding: Option<Coding>

A coding to validate. The system must match the specified code system

codeableConcept: Option<CodeableConcept>

A full codeableConcept to validate. The server returns true if one of the coding values is in the code system, and may also validate that the codings are not in conflict with each other if more than one is present

date: Option<FHIRDateTime>

The date for which the validation should be checked. Normally, this is the current conditions (which is the default values) but under some circumstances, systems need to validate that a correct code was used at some point in the past. A typical example of this would be where code selection is constrained to the set of codes that were available when the patient was treated, not when the record is being edited. Note that which date is appropriate is a matter for implementation policy.

abstract_: Option<FHIRBoolean>

If this parameter has a value of true, the client is stating that the validation is being performed in a context where a concept designated as ‘abstract’ is appropriate/allowed to be used, and the server should regard abstract codes as valid. If this parameter is false, abstract codes are not considered to be valid.

Note that. ‘abstract’ is a property defined by many HL7 code systems that indicates that the concept is a logical grouping concept that is not intended to be used asa ‘concrete’ concept to in an actual patient/care/process record. This language is borrowed from Object Orienated theory where ‘asbtract’ objects are never instantiated. However in the general record and terminology eco-system, there are many contexts where it is appropraite to use these codes e.g. as decision making criterion, or when editing value sets themselves. This parameter allows a client to indicate to the server that it is working in such a context.

displayLanguage: Option<FHIRCode>

Specifies the language to be used for description when validating the display property